# GrimoireLab Toolkit [![Build Status](https://travis-ci.org/chaoss/grimoirelab-toolkit.svg?branch=master)](https://travis-ci.org/chaoss/grimoirelab-toolkit) [![Coverage Status](https://img.shields.io/coveralls/chaoss/grimoirelab-toolkit.svg)](https://coveralls.io/r/chaoss/grimoirelab-toolkit?branch=master)

Toolkit of common functions used across GrimoireLab projects.

This package provides a library composed by functions widely used in other
GrimoireLab projects. These function deal with date handling, introspection,
URIs/URLs, among other topics.

## Requirements

* Python >= 3.4
* python3-dateutil >= 2.6

## Installation

```
$ pip3 install -r requirements.txt
$ python3 setup.py install
```

## License

Licensed under GNU General Public License (GPL), version 3 or later.
